@@ -14,6 +14,9 @@ GType champlain_state_get_type (void);
 #include <champlain/champlain-view.h>
 #define CHAMPLAIN_TYPE_SCROLL_MODE champlain_scroll_mode_get_type()
 GType champlain_scroll_mode_get_type (void);
+#include <champlain/champlain-selection-layer.h>
+#define CHAMPLAIN_TYPE_SELECTION_MODE champlain_selection_mode_get_type()
+GType champlain_selection_mode_get_type (void);
 #include <champlain/champlain-map-source.h>
 #define CHAMPLAIN_TYPE_MAP_PROJECTION champlain_map_projection_get_type()
 GType champlain_map_projection_get_type (void);
