@@ -56,10 +56,8 @@ struct _ChamplainMapSourceFactoryClass
 GType champlain_map_source_factory_get_type (void);
 
 ChamplainMapSourceFactory * champlain_map_source_factory_dup_default (void);
-ChamplainMapSourceFactory * champlain_map_source_factory_get_default (void) G_GNUC_DEPRECATED;
 
 GSList * champlain_map_source_factory_dup_list (ChamplainMapSourceFactory *factory);
-GSList * champlain_map_source_factory_get_list (ChamplainMapSourceFactory *factory) G_GNUC_DEPRECATED;
 
 ChamplainMapSource * champlain_map_source_factory_create (ChamplainMapSourceFactory *factory,
     const gchar *id);
@@ -67,7 +65,7 @@ ChamplainMapSource * champlain_map_source_factory_create (ChamplainMapSourceFact
 gboolean
 champlain_map_source_factory_register (ChamplainMapSourceFactory *factory,
     ChamplainMapSourceDesc *desc, ChamplainMapSourceConstructor constructor,
-    gpointer user_data);
+    gpointer data);
 
 #define CHAMPLAIN_MAP_SOURCE_OSM_MAPNIK "osm-mapnik"
 #define CHAMPLAIN_MAP_SOURCE_OSM_OSMARENDER "osm-osmarender"
